@@ -20,6 +20,11 @@
 	case '2':\
 		oparg->CHECK_MODE = AFTER;\
 		break;\
+\
+	case '0':	/* コンペアを行わない */\
+		oparg->CHECK = NOT;\
+		oparg->CHECK_MODE = NOT;\
+		break;\
 \
 	default:\
 		fprintf(stderr, "コンペアモードの指定値が正しくありません\n");\
@@ -40,19 +45,10 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	int result;
 
 	/* 引数解析 */
-	while((result = getopt(argc, argv, "0b:iIlLmMor:t:vw:")) != -1)
+	while((result = getopt(argc, argv, "b:iIlLmMor:t:vw:")) != -1)
 	{
 		switch(result)
 		{
-		case '0':	/* コンペアを行わない */
-			if(oparg->EFFECT == NOT)
-			{
-				oparg->EFFECT = EXIST;
-			}
-			oparg->CHECK = NOT;
-			oparg->CHECK_MODE = NOT;
-			break;
-
 		case 'b':	/* バッファサイズを指定 */
 			if(oparg->EFFECT == NOT)
 			{
