@@ -3,15 +3,13 @@
 
 #define _GNU_SOURCE
 
-#include "print_error.h" // inline
+#include "print_error.h"
 #include "struct_CPInfo.h"
 
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 
-static struct timespec time_s[2];
-
 /* 関数プロトタイプ */
 static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd);
 
@@ -19,16 +17,17 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 *******************************************************************************/
 static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd)
 {
-	errno = 0;
+	struct timespec time_s[2];
+
+	lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
 /*
+	errno = 0;
 	if(lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 	{
 		print_error("lchown", __FILE__, __LINE__, cpdd);
 	}
 */
 
-	lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
-
 	time_s[0].tv_sec = stat_buf->st_atime;
 	time_s[1].tv_sec = stat_buf->st_mtime;
 
