@@ -441,7 +441,7 @@ static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, con
 			ch_time_and_mod_dir(cpinfo, stat_buf, cpdd);
 		}
 
-		if(oparg->M == MOVE) { REMOVE_SOURCE_RMDIR }
+		if((oparg->M == MOVE) && ((oparg->CHECK == NOT) || (oparg->CHECK_MODE == BEFORE))) { REMOVE_SOURCE_RMDIR }
 	}
 
 	return file_list;
@@ -673,11 +673,7 @@ static void check_write_file_or_create_link(const OPArg *oparg, const SDir *sdir
 
 		if((oparg->M == MOVE) && (cpinfo->dst_para == WRITE))
 		{
-			if(oparg->CHECK == NOT)
-			{
-				REMOVE_SOURCE_UNLINK
-			}
-			else if((oparg->CHECK_MODE == BEFORE) && (cpinfo->hash_check == true))
+			if((oparg->CHECK == NOT) || ((oparg->CHECK_MODE == BEFORE) && (cpinfo->hash_check == true)))
 			{
 				REMOVE_SOURCE_UNLINK
 			}
@@ -687,7 +683,7 @@ static void check_write_file_or_create_link(const OPArg *oparg, const SDir *sdir
 	{
 		create_symboliclink(oparg, cpinfo, cpdd);
 
-		if((oparg->M == MOVE) && (cpinfo->dst_para == WRITE))
+		if((oparg->M == MOVE) && (cpinfo->dst_para == WRITE) && (oparg->CHECK_MODE != AFTER))
 		{
 			REMOVE_SOURCE_UNLINK
 		}
@@ -813,28 +809,30 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_list, CPInfo *cpinfo_tmp, CPDD *cpdd)
 {
 	DIR *dp = NULL;
-	struct dirent *entry = NULL;
-	const char *d_name;
 	const char *src_dir = cpinfo_tmp->src;
-	const char *dst_dir = cpinfo_tmp->dst;
+	const int src_dir_len = strlen(src_dir);
 
 	if((dp = opendir(src_dir)) != NULL)
 	{
+		struct dirent *entry = NULL;
+		const char *d_name;
+		const char *dst_dir = cpinfo_tmp->dst;
+		const int dst_dir_len = strlen(dst_dir);
+
 		while((entry = readdir(dp)) != NULL)
 		{
 			d_name = entry->d_name;
+
 			/* strcmpは等しければ0を返す（0は偽） */
 			if(strcmp(d_name, ".") && strcmp(d_name, ".."))
 			{
-				int fdir = strlen(src_dir);
-				int tdir = strlen(dst_dir);
-				int d_len = strlen(d_name);
+				const int d_name_len = strlen(d_name);
 
 				CPInfo *cpinfo = malloc_cpinfo();
 
 				/* +2は、 \0 と / の分 */
-				cpinfo->src = xmalloc(fdir + d_len + 2);
-				cpinfo->dst = xmalloc(tdir + d_len + 2);
+				cpinfo->src = xmalloc(src_dir_len + d_name_len + 2);
+				cpinfo->dst = xmalloc(dst_dir_len + d_name_len + 2);
 				cpinfo->dstfs = cpinfo_tmp->dstfs;
 				cpinfo->copy_mode = cpinfo_tmp->copy_mode;
 				/*
@@ -891,6 +889,16 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 		fprintf(stderr, "`%s' を読み取れませんでした\n", src_dir);
 	}
 
+	/* フォルダ削除用 */
+	CPInfo *cpinfo_dir = malloc_cpinfo();
+	cpinfo_dir->src = xmalloc(src_dir_len + 1);
+	strcpy(cpinfo_dir->src, cpinfo_tmp->src);
+	cpinfo_dir->src_type = cpinfo_tmp->src_type;
+	cpinfo_dir->dst_para = cpinfo_tmp->dst_para;
+	cpinfo_dir->src_para = cpinfo_tmp->src_para;
+	cpinfo_dir->is_rmdir = true;
+	file_list = append_list((void *)cpinfo_dir, file_list);
+
 	return file_list;
 }
 
@@ -921,6 +929,7 @@ static inline CPInfo * malloc_cpinfo(void)
 	cpinfo->src_md5 = NULL;
 	cpinfo->src_size = 0;
 	cpinfo->dst_size = 0;
+	cpinfo->is_rmdir = false;
 
 	return cpinfo;
 }
