@@ -16,7 +16,7 @@ static inline void compare_verify_one(const OPArg *oparg, const SDir *sdir, CPIn
 	switch(oparg->CHECK)
 	{
 	case V_FIVE:
-		if((cpinfo->src_md5 != NULL) && (cpinfo->dst_size > 0) && (cpinfo->dst_para == WRITE))
+		if((cpinfo->src_md5 != NULL) && (cpinfo->dst_para == WRITE))
 		{
 			verify_hash(oparg, sdir, cpinfo, cpdd);
 		}
