@@ -2,7 +2,7 @@
 
 #include "struct_OPArg.h"
 #include "struct_SDir.h"
-#include "xmalloc.h" // inline
+#include "xmalloc.h"
 
 #include <string.h>
 #include <limits.h>
@@ -39,7 +39,7 @@ OPArg * read_conf(const SDir *sdir);
 OPArg * read_conf(const SDir *sdir)
 {
 	char buf[INPUT_LEN];
-	OPArg *oparg = xmalloc(sizeof(OPArg));
+	OPArg *oparg = xmalloc_inline(sizeof(OPArg));
 	oparg->CHECK = NOT;
 	oparg->I = NOT;
 	oparg->L = NOT;
