@@ -129,6 +129,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	_Bool stat_src = false;
 	_Bool open_dst = false;
 	_Bool is_direct_io = false;
+	int return_dst_ftruncate = 0;
 
 	src_size_local = 0;
 	written_size[0] = 0;
@@ -398,6 +399,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		/* open時にO_TRUNCするようにしたので、ここの処理は必要ない気がする。 */
 		if(ftruncate(idst, 0) == -1)
 		{
+			return_dst_ftruncate = -1;
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
 		}
 
@@ -469,7 +471,9 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		cpdd->total_error += total_write_error;
 	}
 
-	if((open_src == true) && (open_dst == true) && (src_size_local <= total_write_local))
+	if(((open_src == true) && (open_dst == true)) &&
+		(((0 < src_size_local) && (src_size_local <= total_write_local)) || ((src_size_local == 0) && (return_dst_ftruncate == 0)))
+	)
 	{
 		cpinfo->dst_para = WRITE;
 	}
