@@ -5,4 +5,4 @@
 
 extern char *write_now;
 
-extern void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
+extern void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
