@@ -42,7 +42,7 @@ void handler(int sig)
 	if(write_now != NULL)
 	{
 		unlink(write_now);
-		fprintf(stderr, "書き込み中の %s を削除しました\n", write_now);
+		fprintf(stderr, "書き込み中の `%s' を削除しました\n", write_now);
 	}
 
 	exit(EXIT_FAILURE);
