@@ -55,7 +55,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		psize = sysconf(_SC_PAGESIZE);
 	}
 
-	_Bool open_flag;
+	_Bool is_open;
 
 	errno = 0;
 	if((fd = open(cpinfo->dst, O_NOATIME | O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
@@ -65,25 +65,25 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		case EPERM:
 			if((fd = open(cpinfo->dst, O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 			{
-				open_flag = false;
+				is_open = false;
 			}
 			else
 			{
-				open_flag = true;
+				is_open = true;
 			}
 			break;
 
 		default:
-			open_flag = false;
+			is_open = false;
 			break;
 		}
 	}
 	else
 	{
-		open_flag = true;
+		is_open = true;
 	}
 
-	if(open_flag == true)
+	if(is_open == true)
 	{
 		o_direct(oparg, sdir, cpinfo, cpdd);
 	}
@@ -92,7 +92,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		verify_md5sum(oparg, sdir, cpinfo, cpdd);
 	}
 
-	if((open_flag == true) && (close(fd) == -1))
+	if((is_open == true) && (close(fd) == -1))
 	{
 		print_error("close", __FILE__, __LINE__, cpdd);
 	}
