@@ -3,4 +3,4 @@
 #include "struct_OPArg.h"
 #include "struct_SDir.h"
 
-void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd);
+void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
