@@ -33,21 +33,21 @@ void write_conf(const SDir *sdir)
 	const int INPUT_LEN = 256;
 	char stdin_buf[INPUT_LEN];
 
-	_Bool verify_flag = false;
+	_Bool is_verify = false;
 	char hash_check_mode = '@';
-	_Bool hash_check_log_flag = false;
+	_Bool is_hash_check_log = false;
 
 	int buffer_size = 0;
 
-	_Bool info_flag = false;
-	_Bool overwrite_flag = false;
+	_Bool is_info = false;
+	_Bool is_overwrite = false;
 	char write_mode = '@';
-	_Bool delete_flag = false;
+	_Bool is_delete = false;
 
-	_Bool thread_flag = false;
+	_Bool is_thread = false;
 	char thread_mode = '@';
 
-	_Bool view_flag = false;
+	_Bool is_view = false;
 
 	puts("設定の変更を行います");
 
@@ -61,7 +61,7 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			verify_flag = true;
+			is_verify = true;
 
 			puts("");
 			puts("ベリファイモードを選んでください");
@@ -85,12 +85,12 @@ void write_conf(const SDir *sdir)
 
 				if(stdin_buf[0] == 'y')
 				{
-					hash_check_log_flag = true;
+					is_hash_check_log = true;
 				}
 			}
 			else
 			{
-				verify_flag = false;
+				is_verify = false;
 				puts("ベリファイオプションを無効にします");
 				fflush(stdout);
 			}
@@ -133,11 +133,11 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			info_flag = true;
+			is_info = true;
 		}
 	}
 
-	if(info_flag == false)
+	if(is_info == false)
 	{
 		puts("");
 		puts("上書きモードを変更しますか? (初期設定は、サイズ又は日付が異なる場合に上書き)");
@@ -148,7 +148,7 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			overwrite_flag = true;
+			is_overwrite = true;
 
 			puts("");
 			puts("上書きモードを選んでください");
@@ -167,7 +167,7 @@ void write_conf(const SDir *sdir)
 			}
 			else
 			{
-				overwrite_flag = false;
+				is_overwrite = false;
 				puts("上書きモードを初期設定にします");
 				fflush(stdout);
 			}
@@ -184,7 +184,7 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			delete_flag = true;
+			is_delete = true;
 		}
 	}
 
@@ -198,7 +198,7 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			thread_flag = true;
+			is_thread = true;
 
 			puts("");
 			puts("モードを選んでください (初期設定は自動判別)");
@@ -216,7 +216,7 @@ void write_conf(const SDir *sdir)
 			}
 			else
 			{
-				thread_flag = false;
+				is_thread = false;
 				puts("スレッドモードを初期設定にします");
 				fflush(stdout);
 			}
@@ -233,19 +233,19 @@ void write_conf(const SDir *sdir)
 
 		if(stdin_buf[0] == 'y')
 		{
-			view_flag = true;
+			is_view = true;
 		}
 	}
 
 	/* 設定をファイルに保存する */
 	if(
-		(true == verify_flag) ||
+		(true == is_verify) ||
 		(0 < buffer_size) ||
-		(true == info_flag) ||
-		(true == overwrite_flag) ||
-		(true == delete_flag) ||
-		(true == thread_flag) ||
-		(true == view_flag)
+		(true == is_info) ||
+		(true == is_overwrite) ||
+		(true == is_delete) ||
+		(true == is_thread) ||
+		(true == is_view)
 	)
 	{
 		/* フォルダが存在しない場合は作成 */
@@ -287,7 +287,7 @@ void write_conf(const SDir *sdir)
 
 			puts(" ");
 
-			if(verify_flag == true)
+			if(is_verify == true)
 			{
 				if(fputc('r', config) == EOF)
 				{
@@ -309,7 +309,7 @@ void write_conf(const SDir *sdir)
 				printf("ベリファイモード : %c\n", hash_check_mode);
 			}
 
-			if(hash_check_log_flag == true)
+			if(is_hash_check_log == true)
 			{
 				if(
 					(fputs("l", config) == EOF) ||
@@ -342,7 +342,7 @@ void write_conf(const SDir *sdir)
 				printf("バッファサイズ : %d\n", buffer_size);
 			}
 
-			if(info_flag == true)
+			if(is_info == true)
 			{
 				if(
 					(fputs("i", config) == EOF) ||
@@ -357,7 +357,7 @@ void write_conf(const SDir *sdir)
 				puts("上書き確認する");
 			}
 
-			if(overwrite_flag == true)
+			if(is_overwrite == true)
 			{
 				if(fputs("w", config) == EOF)
 				{
@@ -379,7 +379,7 @@ void write_conf(const SDir *sdir)
 				printf("上書きモード   : %c\n", write_mode);
 			}
 
-			if(delete_flag == true)
+			if(is_delete == true)
 			{
 				if(
 					(fputs("m", config) == EOF) ||
@@ -394,7 +394,7 @@ void write_conf(const SDir *sdir)
 				puts("移動モード");
 			}
 
-			if(thread_flag == true)
+			if(is_thread == true)
 			{
 				if(fputs("t", config) == EOF)
 				{
@@ -416,7 +416,7 @@ void write_conf(const SDir *sdir)
 				printf("スレッドモード : %c\n", thread_mode);
 			}
 
-			if(view_flag == true)
+			if(is_view == true)
 			{
 				if(
 					(fputs("v", config) == EOF) ||
