@@ -5,7 +5,7 @@
 #include <stdlib.h>
 
 /* 関数プロトタイプ */
-static inline void * xmalloc0(const size_t size)  __attribute__((always_inline));
+static inline void * xmalloc0(const size_t size) ;
 
 /*******************************************************************************
  * callocのラッパー関数
